      subroutine sky_interp_lite (src_az, src_el, detector,drmdbpath,
     .  list,lptr,lend,x,y,z,azimuth,zenith,milliaz,millizen,leaf_ver,n,
     .  maxen,maxchan, debug, energ_lo,energ_hi,
     .  outmatrix, edif_edge_lo, edif_edge_hi, ienerg,ichan,
     .  drmfiles)
C Written by Colleen A Wilson-Hodge NASA/MSFC 2007-Jul-31  
C Changes 2008-March-06 CAWH - added drmfiles as a returned variable for audit
C  trail info.   
C 2008-March-11 CAWH - changed this to a temporary code for atscat testing.
C The temporary code skips the interpolation step and only uses the first matrix
C that TRFIND gets.
C 2008-March13 CAWH - above change wasn't quite working. Added call to 
C calc_sphere_dist to be consistent with IDL code. 
C 2008-Nov 11 CAWH - added leaf_ver as an input to be passed to
C  parse_drm_filename
c
C Given a source position: src_az, src_el, detector, and 
C a triagulation for a grid of positions on the sky with existing response
C matrices, this coded generates an interpolated response matrix for the desired
C position and detector. The triangulation is done outside of this code so that
C the triangulation can be generated or read once while this code can be called
C multiple times for different source positions. In this routine, first the 
C triangle containing the source position is located in the grid. Then the three
C response matrices corresponding to the vertices of that triangle are read in 
C and linearly interpolated to produce the response at the source position. 
C Note, the matrices are unpacked from the zero-suppressed storage style used in
C the fits files. However, the photon and channel edges, expected to be the same
C for all of the matrices in the database for a given detector, are simply 
C passed through the code for later processing.

C Inputs:
C src_az, src_el = the source azimuth and elevation in S/C coordinates in
C                  degrees
C detector = the detector number of interest (NaI detectors 0-11, BGO 12-13)
C drmdbpath = the path to the grid of response matrices
C LIST,LPTR, LEND - triangulation indices needed by Renka's TRFIND routine.
C X,Y,Z - cartesian coordinates (S/C) for each grid point. Needed for Renka's
C          TRFIND routine.
C Azimuth, Zenith - S/C coordinates in degrees for each grid point. Needed to
C                   find the corresponding response file.
C milliaz, millizen - S/C coordinates in millidegress for each grid point. Used
C by parse_drm_filename
C leaf_ver - version number of leaf drm files. Used by parse_drm_filename
C N - the number of points in the triangulation
C maxen = the maximum number of photon energies included in the output matrix
C maxchan = the maximum number of channel energies included in the output matrix
C debug >1 increases verbosity
C OUTPUTS:
C energ_lo, energ_hi = the photon energy boundaries for the output matrix
C echan_min, echan_max = the channel energy boundaries for the output matrix
C outmatrix = the output response matrix, linearly interpolated from the 3
C             matrices at the vertices of a triangle containing the source 
C             position.
C ichan, ienerg = the actual number of channel energies, photon energies
C                 included in the output matrix.
C Routines called:
C TRFIND - finds the triangle containing the user's point (Renka, alg772)
C parse_drm_filename - using the azimuth and zenith from the 3 triangle
C                      vertices,the detector number, and the path to the
C                      drm database, assembles the filenames for the drms to
C                      be used in the interpolation.
C readgbmdrm - reads the gbmdrm fits files in the database
c readchane - reads the ebounds extension for the gbmdrm fits files.
c intrc0sp - Does a linear interpolation on the triangle. Adapted from Renka's
C            INTRC0, algorithm 773.
      implicit none
C inputs
      real src_az,src_el,X(*),Y(*),Z(*),Azimuth(*),Zenith(*)
      integer detector,maxen,maxchan,list(*),lptr(*),lend(*),n,
     . debug, milliaz(*), millizen(*)
      character*3 leaf_ver
      character*80 drmdbpath
C outputs
      real energ_lo(*), energ_hi(*),
     .     outmatrix(maxen,maxchan),edif_edge_lo(maxen,maxchan),
     .     edif_edge_hi(maxen,maxchan)
      integer ichan,ienerg
C local variables      
      INTEGER  i,j,k,ist,i1,i2,i3, testlen,
     .  lmsg, lout,ier
      REAL plat,plon,p(3),sf,b1,b2,b3,matrix1(maxen,maxchan),
     .  matrix2(maxen,maxchan), matrix3(maxen,maxchan)
      real dist1,dist2,dist3,mindist
      character*40 drmfiles(3),outfile
      character*90 drmpath
      character*130 drmfullname(3)
c      print*,'Inside sky_interp_lite: '
c      print*,src_az,src_el,detector,drmdbpath,maxen,maxchan,ienerg,ichan
c      print*,(drmfiles(i),i=1,3)
            
C transform src_az and src_el to cartesian coordinates
      sf = ATAN(1.)/45.
      plat = src_el*sf
      plon = src_az*sf     
      P(1) = COS(PLAT)*COS(PLON)
      P(2) = COS(PLAT)*SIN(PLON)
      P(3) = SIN(PLAT)
C
C Find the vertex indexes of a triangle containing P.
C  
c      print*,'Calling TRFIND'
      CALL TRFIND(IST,P,N,X,Y,Z,LIST,LPTR,LEND, B1,B2,B3,
     .            I1,I2,I3)
c      print*,'i1,i2,i3 = ',i1,i2,i3
C Find the closest point on the sphere to be consistent with IDL code
      call calc_sphere_dist(src_az,90.-src_el,azimuth(i1),zenith(i1),  
     . dist1)
      call calc_sphere_dist(src_az,90.-src_el,azimuth(i2),zenith(i2),  
     . dist2)
      call calc_sphere_dist(src_az,90.-src_el,azimuth(i3),zenith(i3),  
     . dist3)
      mindist = min(dist1,dist2,dist3)
      if (dist2.eq.mindist) i1=i2
      if (dist3.eq.mindist) i1=i3    
C get the names for the desired drm files
        call parse_drm_filename(detector,milliaz(i1),
     .   millizen(i1), leaf_ver,drmdbpath,drmpath,drmfiles(1))
c        call parse_drm_filename(detector, milliaz(i2),
c     .   millizen(i2), drmdbpath,drmpath,drmfiles(2))
c        call parse_drm_filename(detector,milliaz(i3),
c     .   millizen(i3), drmdbpath,drmpath,drmfiles(3))
        drmfiles(2)='notused'
	drmfiles(3)='notused'
c        print*,'drmpath = ',drmpath
        testlen = len_trim(drmpath)
        do k=1,3
	  drmfullname(k) = drmpath(1:testlen)//drmfiles(k)
c	  print*,drmfullname(k)
        enddo
C zero out the matrices	
	do i=1,maxen
	  do j=1,maxchan
	    matrix1(i,j)=0.
	    matrix2(i,j)=0.
	    matrix3(i,j)=0.
	    outmatrix(i,j)=0.
	  enddo  
	enddo    
        call readgbmdrm(drmfullname(1), maxen, maxchan,
     .       debug,energ_lo, energ_hi, outmatrix,ichan, ienerg)
c        call readgbmdrm(drmfullname(2), maxen, maxchan,
c     .       debug,energ_lo, energ_hi, matrix2,ichan, ienerg)
c        call readgbmdrm(drmfullname(3), maxen, maxchan,
c     .       debug,energ_lo, energ_hi, matrix3,ichan, ienerg)
c        print*,'read 1 drm'
c        call readchane(drmfullname(3),maxchan,echan_min,
c     .       echan_max, ichan)
c get the channel energies for each pixel in the 3rd compressed matrix
        call readpixeedges(drmfullname(1),maxchan,maxen,debug,
     .    ichan,ienerg,
     .    edif_edge_lo,edif_edge_hi)
c       print*,'read pixedges'
C *** C-0 interpolation (INTRC0).
c      CALL INTRC0SP (B1,B2,B3,I1,I2,I3,ienerg,ichan,
c     .      maxen, maxchan,	  
c     .      matrix1,
c     .      matrix2,
c     .      matrix3,
c     .      outmatrix,IER)
c      print*,'interpolation complete'
c      if(debug.gt.1) 
c     . print*,'matrix1,matrix2,maxtrix3,outmaxtrix(1,1): ',
c     . matrix1(1,1),matrix2(1,1),matrix3(1,1),outmatrix(1,1)
c      IF (IER .LT. 0) THEN
c        WRITE (*,430) I, I, IER
c        STOP
c      ENDIF
C   
C *** Normal termination.
C
      if(debug.gt.1) WRITE (*,580)
  580 FORMAT (//5X,'No error encountered.'/)
C Error message Formats:
C
c  430 FORMAT (//5X,'Error in INTRC0:  I = ',I3,', J = ',I3,
c     .        ', IER = ',I2/)
c      print*,'returning from sky_interp_lite'
      RETURN
      END

 
